==> runawfe-free-server-4.3.0.tar.gz: runawfe-free-server-4.3.0/wfe-web/src/main/java/ru/runa/wf/web/MessagesProcesses.java <==
package ru.runa.wf.web;

import ru.runa.common.web.StrutsMessage;

public final class MessagesProcesses {

    public static final StrutsMessage BUTTON_CANCEL_PROCESS = new StrutsMessage("button.cancel_process");
    public static final StrutsMessage TITLE_PROCESS_DEFINITIONS = new StrutsMessage("title.process_definitions");
    public static final StrutsMessage TITLE_DEPLOY_DEFINITION = new StrutsMessage("title.deploy_definition");
    public static final StrutsMessage TITLE_REDEPLOY_DEFINITION = new StrutsMessage("title.redeploy_definition");
    public static final StrutsMessage BUTTON_DEPLOY_DEFINITION = new StrutsMessage("button.deploy_definition");
    public static final StrutsMessage BUTTON_UNDEPLOY_DEFINITION = new StrutsMessage("button.undeploy_definition");
    public static final StrutsMessage TITLE_DEFINITIONS_HISTORY = new StrutsMessage("title.definitions_history");
    public static final StrutsMessage TITLE_PROCESSES = new StrutsMessage("title.processes");
    public static final StrutsMessage TITLE_INSANCE_SWINLANE_LIST = new StrutsMessage("title.process_swimlane_list");
    public static final StrutsMessage TITLE_INSANCE_TASKS_LIST = new StrutsMessage("title.process_tasks_list");
    public static final StrutsMessage TITLE_INSANCE_VARIABLE_LIST = new StrutsMessage("title.process_variable_list");
    public static final StrutsMessage TITLE_PROCESS = new StrutsMessage("title.process");
    public static final StrutsMessage TITLE_PROCESS_DEFINITION = new StrutsMessage("title.process_definition");
    public static final StrutsMessage TITLE_PROCESS_DEFINITION_CHANGES = new StrutsMessage("title.process_definition_changes");
    public static final StrutsMessage TITLE_TASKS = new StrutsMessage("title.tasks");
    public static final StrutsMessage TITLE_OBSERVABLE_TASKS = new StrutsMessage("title.observable.tasks");
    public static final StrutsMessage TITLE_OBSERVABLE_EXECUTORS = new StrutsMessage("title.observable.executors");
    public static final StrutsMessage TITLE_EXECUTOR_TASKS = new StrutsMessage("title.executor_tasks");
    public static final StrutsMessage TITLE_ACTOR_TASKS = new StrutsMessage("title.actor_tasks");
    public static final StrutsMessage TITLE_GROUP_TASKS = new StrutsMessage("title.group_tasks");
    public static final StrutsMessage TITLE_TASK_FORM = new StrutsMessage("title.task_form");
    public static final StrutsMessage TITLE_VIEW_ONLY = new StrutsMessage("title.task_view_only");
    public static final StrutsMessage TITLE_PROCESS_GRAPH = new StrutsMessage("title.process_graph");
    public static final StrutsMessage TITLE_HISTORY = new StrutsMessage("title.history");
    public static final StrutsMessage LABEL_REDEPLOY_PROCESS_DEFINIION = new StrutsMessage("label.redeploy_process_definition");
    public static final StrutsMessage LABEL_SHOW_DEPLOY_DEFINITION_CONTROLS = new StrutsMessage("label.show_deploy_definition_controls");
    public static final StrutsMessage LABEL_HIDE_DEPLOY_DEFINITION_CONTROLS = new StrutsMessage("label.hide_deploy_definition_controls");
    public static final StrutsMessage PROCESS_STARTED = new StrutsMessage("process.started");
    public static final StrutsMessage PROCESS_ACTIVATE = new StrutsMessage("process.activate");
    public static final StrutsMessage PROCESS_ACTIVATE_FAILED_TOKENS = new StrutsMessage("process.activate.failed.tokens");
    public static final StrutsMessage PROCESS_ACTIVATED = new StrutsMessage("process.activated");
    public static final StrutsMessage FAILED_PROCESSES_ACTIVATED = new StrutsMessage("failed.processes.activated");
    public static final StrutsMessage PROCESS_SUSPEND = new StrutsMessage("process.suspend");
    public static final StrutsMessage PROCESS_SUSPENDED = new StrutsMessage("process.suspended");
    public static final StrutsMessage PROCESS_CANCELED = new StrutsMessage("process.canceled");
    public static final StrutsMessage PROCESS_REMOVED = new StrutsMessage("process.removed");
    public static final StrutsMessage PROCESS_UPGRADED_TO_DEFINITION_VERSION = new StrutsMessage("process.upgraded.to.definition.version");
    public static final StrutsMessage PROCESS_UPGRADE_TO_DEFINITION_VERSION = new StrutsMessage("process.upgrade.to.definition.version");
    public static final StrutsMessage PROCESSES_UPGRADE_TO_DEFINITION_VERSION = new StrutsMessage("processes.upgrade.to.definition.version");
    public static final StrutsMessage PROCESSES_UPGRADED_TO_DEFINITION_VERSION = new StrutsMessage("processes.upgraded.to.definition.version");
    public static final StrutsMessage LABEL_SHOW_GRAPH_HISTORY = new StrutsMessage("label.manage_graph_history");
    public static final StrutsMessage LABEL_SHOW_GANTT_DIAGRAM = new StrutsMessage("label.show_gantt_diagram");
    public static final StrutsMessage LABEL_DEFINITIONS_ARCHIVE = new StrutsMessage("process_definition.archive");
    public static final StrutsMessage LABEL_DEPLOY_APPLY_TYPE = new StrutsMessage("batch_presentation.process_definition.application_type");
    public static final StrutsMessage LABEL_DEPLOY_APPLY_NEW = new StrutsMessage("batch_presentation.process_definition.application_type.new.label");
    public static final StrutsMessage LABEL_DEPLOY_APPLY_ALL = new StrutsMessage("batch_presentation.process_definition.application_type.all.label");
    public static final StrutsMessage PROCESS_STARTER_NAME = new StrutsMessage("process_starter.name");
    public static final StrutsMessage LABEL_STATE_NAME = new StrutsMessage("label.state_name");
    public static final StrutsMessage LABEL_PARENT_PROCESS = new StrutsMessage("label.parent_process");
    public static final StrutsMessage LABEL_START_PROCESS = new StrutsMessage("label.start_process");
    public static final StrutsMessage LABEL_SWIMLANE = new StrutsMessage("label.swimlane");
    public static final StrutsMessage LABEL_SWIMLANE_NAME = new StrutsMessage("label.swimlane_name");
    public static final StrutsMessage LABEL_SWIMLANE_ASSIGNMENT = new StrutsMessage("label.swimlane_assigned_to");
    public static final StrutsMessage LABEL_CREATE_TIME = new StrutsMessage("label.create_time");
    public static final StrutsMessage LABEL_END_TIME = new StrutsMessage("label.end_time");
    public static final StrutsMessage LABEL_CURRENT_DURATION = new StrutsMessage("label.current_duration");
    public static final StrutsMessage LABEL_REMAINING_TIME = new StrutsMessage("label.remaining_time");
    public static final StrutsMessage LABEL_ASSIGNMENT_TIME = new StrutsMessage("label.assignment_time");
    public static final StrutsMessage LINK_UPDATE_SWIMLANE = new StrutsMessage("link.update_swimlane");
    public static final StrutsMessage BUTTON_UPDATE_SWIMLANE = new StrutsMessage("button.update_swimlane");
    public static final StrutsMessage LABEL_SWIMLANE_NEW_EXECUTOR = new StrutsMessage("label.swimlane_new_executor");
    public static final StrutsMessage LABEL_NO_SWIMLANES = new StrutsMessage("label.no_swimlanes");
    public static final StrutsMessage LINK_UPDATE_VARIABLE = new StrutsMessage("link.update_variable");
    public static final StrutsMessage BUTTON_UPDATE_VARIABLE = new StrutsMessage("button.update_variable");
    public static final StrutsMessage BUTTON_FORM = new StrutsMessage("button.form");
    public static final StrutsMessage BUTTON_COMPLETE = new StrutsMessage("button.complete");
    public static final StrutsMessage BUTTON_ACCEPT_TASK = new StrutsMessage("button.accept_task");
    public static final StrutsMessage BUTTON_DELEGATE_TASK = new StrutsMessage("button.delegate_task");
    public static final StrutsMessage BUTTON_DELEGATE_TASKS = new StrutsMessage("button.delegate_tasks");
    public static final StrutsMessage BUTTON_EXPORT_EXCEL = new StrutsMessage("button.export_excel");
    public static final StrutsMessage TITLE_UPDATE_VARIABLE = new StrutsMessage("title.update_variable");
    public static final StrutsMessage LABEL_VARIABLE_NAME = new StrutsMessage("label.variable_name");
    public static final StrutsMessage LABEL_VARIABLE_VALUE = new StrutsMessage("label.variable_value");
    public static final StrutsMessage LABEL_VARIABLE_TYPE = new StrutsMessage("label.variable_type");
    public static final StrutsMessage LABEL_VARIABLE_SCRIPTING_VALUE = new StrutsMessage("label.variable_script_value");
    public static final StrutsMessage LABEL_VARIABLE = new StrutsMessage("label.variable");
    public static final StrutsMessage LABEL_VARIABLE_NULL_VALUE = new StrutsMessage("label.variable_null_value");
    public static final StrutsMessage LABEL_VARIABLE_OLD_VALUE = new StrutsMessage("label.variable_old_value");
    public static final StrutsMessage LABEL_VARIABLE_NEW_VALUE = new StrutsMessage("label.variable_new_value");
    public static final StrutsMessage LABEL_NO_VARIABLES = new StrutsMessage("label.no_variables");
    public static final StrutsMessage TASK_COMPLETED = new StrutsMessage("task.completed");
    public static final StrutsMessage LABEL_SHOW_TASKS_HISTORY = new StrutsMessage("label.manage_tasks_history");
    public static final StrutsMessage LABEL_TASK_HISTORY_TABLE_NAME = new StrutsMessage("label.task_history_table_name");
    public static final StrutsMessage LABEL_TASK_HISTORY_TABLE_TASK_NAME = new StrutsMessage("label.task_history_table_task_name");
    public static final StrutsMessage LABEL_TASK_HISTORY_TABLE_EXECUTOR = new StrutsMessage("label.task_history_table_executor");
    public static final StrutsMessage LABEL_TASK_HISTORY_TABLE_START_DATE = new StrutsMessage("label.task_history_table_start_date");
    public static final StrutsMessage LABEL_TASK_HISTORY_TABLE_END_DATE = new StrutsMessage("label.task_history_table_end_date");
    public static final StrutsMessage LABEL_TASK_HISTORY_TABLE_DURATION = new StrutsMessage("label.task_history_table_duration");
    public static final StrutsMessage LABEL_UPDATE_CURRENT_VERSION = new StrutsMessage("batch_presentation.process_definition.update_current_version");
    public static final StrutsMessage TITLE_SUBPROCESSES_LIST = new StrutsMessage("title.process_subprocess_list");
    public static final StrutsMessage LINK_SHOW_TASKS = new StrutsMessage("link.show_tasks");

}

==> runawfe-free-server-4.5.0.tar.gz: runawfe-free-server-4.5.0/wfe-web/src/main/java/ru/runa/wf/web/MessagesProcesses.java <==
package ru.runa.wf.web;

import ru.runa.common.web.StrutsMessage;

public final class MessagesProcesses {

    public static final StrutsMessage BUTTON_CANCEL_PROCESS = new StrutsMessage("button.cancel_process");
    public static final StrutsMessage BUTTON_CANCEL_PROCESSES = new StrutsMessage("button.cancel_processes");
    public static final StrutsMessage BUTTON_ACTIVATE_PROCESSES = new StrutsMessage("button.activate_processes");
    public static final StrutsMessage BUTTON_RESTORE_PROCESS = new StrutsMessage("button.restore_process");
    public static final StrutsMessage TITLE_PROCESS_DEFINITIONS = new StrutsMessage("title.process_definitions");
    public static final StrutsMessage TITLE_DEPLOY_DEFINITION = new StrutsMessage("title.deploy_definition");
    public static final StrutsMessage TITLE_REDEPLOY_DEFINITION = new StrutsMessage("title.redeploy_definition");
    public static final StrutsMessage BUTTON_DEPLOY_DEFINITION = new StrutsMessage("button.deploy_definition");
    public static final StrutsMessage BUTTON_UNDEPLOY_DEFINITION = new StrutsMessage("button.undeploy_definition");
    public static final StrutsMessage TITLE_DEFINITIONS_HISTORY = new StrutsMessage("title.definitions_history");
    public static final StrutsMessage TITLE_PROCESSES = new StrutsMessage("title.processes");
    public static final StrutsMessage TITLE_INSANCE_SWINLANE_LIST = new StrutsMessage("title.process_swimlane_list");
    public static final StrutsMessage TITLE_INSANCE_TASKS_LIST = new StrutsMessage("title.process_tasks_list");
    public static final StrutsMessage TITLE_INSANCE_VARIABLE_LIST = new StrutsMessage("title.process_variable_list");
    public static final StrutsMessage TITLE_PROCESS = new StrutsMessage("title.process");
    public static final StrutsMessage TITLE_PROCESS_DEFINITION = new StrutsMessage("title.process_definition");
    public static final StrutsMessage TITLE_PROCESS_DEFINITION_CHANGES = new StrutsMessage("title.process_definition_changes");
    public static final StrutsMessage TITLE_TASKS = new StrutsMessage("title.tasks");
    public static final StrutsMessage TITLE_OBSERVABLE_TASKS = new StrutsMessage("title.observable.tasks");
    public static final StrutsMessage TITLE_OBSERVABLE_EXECUTORS = new StrutsMessage("title.observable.executors");
    public static final StrutsMessage TITLE_EXECUTOR_TASKS = new StrutsMessage("title.executor_tasks");
    public static final StrutsMessage TITLE_ACTOR_TASKS = new StrutsMessage("title.actor_tasks");
    public static final StrutsMessage TITLE_GROUP_TASKS = new StrutsMessage("title.group_tasks");
    public static final StrutsMessage TITLE_TASK_FORM = new StrutsMessage("title.task_form");
    public static final StrutsMessage TITLE_VIEW_ONLY = new StrutsMessage("title.task_view_only");
    public static final StrutsMessage TITLE_PROCESS_GRAPH = new StrutsMessage("title.process_graph");
    public static final StrutsMessage TITLE_HISTORY = new StrutsMessage("title.history");
    public static final StrutsMessage LABEL_REDEPLOY_PROCESS_DEFINIION = new StrutsMessage("label.redeploy_process_definition");
    public static final StrutsMessage LABEL_SHOW_DEPLOY_DEFINITION_CONTROLS = new StrutsMessage("label.show_deploy_definition_controls");
    public static final StrutsMessage LABEL_HIDE_DEPLOY_DEFINITION_CONTROLS = new StrutsMessage("label.hide_deploy_definition_controls");
    public static final StrutsMessage PROCESS_STARTED = new StrutsMessage("process.started");
    public static final StrutsMessage PROCESS_ACTIVATE = new StrutsMessage("process.activate");
    public static final StrutsMessage PROCESS_ACTIVATE_FAILED_TOKENS = new StrutsMessage("process.activate.failed.tokens");
    public static final StrutsMessage PROCESS_ACTIVATED = new StrutsMessage("process.activated");
    public static final StrutsMessage FAILED_PROCESSES_ACTIVATED = new StrutsMessage("failed.processes.activated");
    public static final StrutsMessage PROCESS_SUSPEND = new StrutsMessage("process.suspend");
    public static final StrutsMessage PROCESS_SUSPENDED = new StrutsMessage("process.suspended");
    public static final StrutsMessage PROCESS_CANCELED = new StrutsMessage("process.canceled");
    public static final StrutsMessage PROCESSES_CANCELED = new StrutsMessage("processes.canceled");
    public static final StrutsMessage PROCESS_RESTORED = new StrutsMessage("process.restored");
    public static final StrutsMessage PROCESS_REMOVED = new StrutsMessage("process.removed");
    public static final StrutsMessage PROCESS_UPGRADED_TO_DEFINITION_VERSION = new StrutsMessage("process.upgraded.to.definition.version");
    public static final StrutsMessage PROCESS_UPGRADE_TO_DEFINITION_VERSION = new StrutsMessage("process.upgrade.to.definition.version");
    public static final StrutsMessage PROCESSES_UPGRADE_TO_DEFINITION_VERSION = new StrutsMessage("processes.upgrade.to.definition.version");
    public static final StrutsMessage PROCESSES_UPGRADED_TO_DEFINITION_VERSION = new StrutsMessage("processes.upgraded.to.definition.version");
    public static final StrutsMessage LABEL_SHOW_GRAPH_HISTORY = new StrutsMessage("label.manage_graph_history");
    public static final StrutsMessage LABEL_SHOW_GANTT_DIAGRAM = new StrutsMessage("label.show_gantt_diagram");
    public static final StrutsMessage LABEL_DEFINITIONS_ARCHIVE = new StrutsMessage("process_definition.archive");
    public static final StrutsMessage LABEL_DEPLOY_APPLY_TYPE = new StrutsMessage("batch_presentation.process_definition.application_type");
    public static final StrutsMessage LABEL_DEPLOY_APPLY_NEW = new StrutsMessage("batch_presentation.process_definition.application_type.new.label");
    public static final StrutsMessage LABEL_DEPLOY_APPLY_ALL = new StrutsMessage("batch_presentation.process_definition.application_type.all.label");
    public static final StrutsMessage PROCESS_STARTER_NAME = new StrutsMessage("process_starter.name");
    public static final StrutsMessage LABEL_STATE_NAME = new StrutsMessage("label.state_name");
    public static final StrutsMessage LABEL_PARENT_PROCESS = new StrutsMessage("label.parent_process");
    public static final StrutsMessage LABEL_START_PROCESS = new StrutsMessage("label.start_process");
    public static final StrutsMessage LABEL_SWIMLANE = new StrutsMessage("label.swimlane");
    public static final StrutsMessage LABEL_SWIMLANE_NAME = new StrutsMessage("label.swimlane_name");
    public static final StrutsMessage LABEL_SWIMLANE_ASSIGNMENT = new StrutsMessage("label.swimlane_assigned_to");
    public static final StrutsMessage LABEL_CREATE_TIME = new StrutsMessage("label.create_time");
    public static final StrutsMessage LABEL_END_TIME = new StrutsMessage("label.end_time");
    public static final StrutsMessage LABEL_CURRENT_DURATION = new StrutsMessage("label.current_duration");
    public static final StrutsMessage LABEL_REMAINING_TIME = new StrutsMessage("label.remaining_time");
    public static final StrutsMessage LABEL_ASSIGNMENT_TIME = new StrutsMessage("label.assignment_time");
    public static final StrutsMessage LINK_UPDATE_SWIMLANE = new StrutsMessage("link.update_swimlane");
    public static final StrutsMessage BUTTON_UPDATE_SWIMLANE = new StrutsMessage("button.update_swimlane");
    public static final StrutsMessage LABEL_SWIMLANE_NEW_EXECUTOR = new StrutsMessage("label.swimlane_new_executor");
    public static final StrutsMessage LABEL_NO_SWIMLANES = new StrutsMessage("label.no_swimlanes");
    public static final StrutsMessage LINK_UPDATE_VARIABLE = new StrutsMessage("link.update_variable");
    public static final StrutsMessage BUTTON_UPDATE_VARIABLE = new StrutsMessage("button.update_variable");
    public static final StrutsMessage BUTTON_FORM = new StrutsMessage("button.form");
    public static final StrutsMessage BUTTON_COMPLETE = new StrutsMessage("button.complete");
    public static final StrutsMessage BUTTON_ACCEPT_TASK = new StrutsMessage("button.accept_task");
    public static final StrutsMessage BUTTON_DELEGATE_TASK = new StrutsMessage("button.delegate_task");
    public static final StrutsMessage BUTTON_DELEGATE_TASKS = new StrutsMessage("button.delegate_tasks");
    public static final StrutsMessage BUTTON_EXPORT_EXCEL = new StrutsMessage("button.export_excel");
    public static final StrutsMessage TITLE_UPDATE_VARIABLE = new StrutsMessage("title.update_variable");
    public static final StrutsMessage LABEL_VARIABLE_NAME = new StrutsMessage("label.variable_name");
    public static final StrutsMessage LABEL_VARIABLE_VALUE = new StrutsMessage("label.variable_value");
    public static final StrutsMessage LABEL_VARIABLE_TYPE = new StrutsMessage("label.variable_type");
    public static final StrutsMessage LABEL_VARIABLE_SCRIPTING_VALUE = new StrutsMessage("label.variable_script_value");
    public static final StrutsMessage LABEL_VARIABLE = new StrutsMessage("label.variable");
    public static final StrutsMessage LABEL_VARIABLE_NULL_VALUE = new StrutsMessage("label.variable_null_value");
    public static final StrutsMessage LABEL_VARIABLE_OLD_VALUE = new StrutsMessage("label.variable_old_value");
    public static final StrutsMessage LABEL_VARIABLE_NEW_VALUE = new StrutsMessage("label.variable_new_value");
    public static final StrutsMessage LABEL_NO_VARIABLES = new StrutsMessage("label.no_variables");
    public static final StrutsMessage TASK_COMPLETED = new StrutsMessage("task.completed");
    public static final StrutsMessage LABEL_SHOW_TASKS_HISTORY = new StrutsMessage("label.manage_tasks_history");
    public static final StrutsMessage LABEL_TASK_HISTORY_TABLE_NAME = new StrutsMessage("label.task_history_table_name");
    public static final StrutsMessage LABEL_TASK_HISTORY_TABLE_TASK_NAME = new StrutsMessage("label.task_history_table_task_name");
    public static final StrutsMessage LABEL_TASK_HISTORY_TABLE_EXECUTOR = new StrutsMessage("label.task_history_table_executor");
    public static final StrutsMessage LABEL_TASK_HISTORY_TABLE_START_DATE = new StrutsMessage("label.task_history_table_start_date");
    public static final StrutsMessage LABEL_TASK_HISTORY_TABLE_END_DATE = new StrutsMessage("label.task_history_table_end_date");
    public static final StrutsMessage LABEL_TASK_HISTORY_TABLE_DURATION = new StrutsMessage("label.task_history_table_duration");
    public static final StrutsMessage LABEL_UPDATE_CURRENT_VERSION = new StrutsMessage(
            "batch_presentation.process_definition.update_current_version");
    public static final StrutsMessage TITLE_SUBPROCESSES_LIST = new StrutsMessage("title.process_subprocess_list");
    public static final StrutsMessage LINK_SHOW_TASKS = new StrutsMessage("link.show_tasks");
    public static final StrutsMessage LABEL_GLOBAL = new StrutsMessage("label.global");

    public static final StrutsMessage LABEL_SEND_PROCESS_SIGNAL = new StrutsMessage("label.send_process_signal");
    public static final StrutsMessage ROUTING_PARAMETER_NAME = new StrutsMessage("label.routing_parameter_name");
    public static final StrutsMessage ROUTING_PARAMETER_VALUE = new StrutsMessage("label.routing_parameter_value");
    public static final StrutsMessage PAYLOAD_PARAMETER_NAME = new StrutsMessage("label.payload_parameter_name");
    public static final StrutsMessage PAYLOAD_PARAMETER_VALUE = new StrutsMessage("label.payload_parameter_value");
    public static final StrutsMessage BUTTON_VIEW_DIFFERENCES = new StrutsMessage("button.view_differences");
    public static final StrutsMessage FAILED_VIEW_DIFFERENCES = new StrutsMessage("failed.view_differences");
    public static final StrutsMessage LABEL_NO_DIFFERENCES_FOUND = new StrutsMessage("label.no_differences_found");

    public static final StrutsMessage PROCESS_LOG_CLEAN_SUCCESS = new StrutsMessage("process_log_clean.success");
    public static final StrutsMessage PROCESS_LOG_CLEAN_FAIL = new StrutsMessage("process_log_clean.fail");

    public static final StrutsMessage TITLE_CHAT_ROOMS = new StrutsMessage("title.chat_rooms");
}
